summaryrefslogtreecommitdiff
path: root/gcc/c-tree.h
diff options
context:
space:
mode:
authorsteven <steven@138bc75d-0d04-0410-961f-82ee72b054a4>2010-05-05 21:32:44 +0000
committersteven <steven@138bc75d-0d04-0410-961f-82ee72b054a4>2010-05-05 21:32:44 +0000
commitdcff3217c8608480cbe20b16ccef7da39cec1966 (patch)
tree541f3e3edc7e4a4873031ecdbba69ae40d69cf52 /gcc/c-tree.h
parent00800310dc87e09a34359a22fe685fdcd9fb3a88 (diff)
downloadgcc-dcff3217c8608480cbe20b16ccef7da39cec1966.tar.gz
* stor-layout.c (pending_sizes): Change the type to
VEC(tree,gc) *. (get_pending_sizes, put_pending_size, put_pending_sizes): Update the uses of pending_sizes. * c-decl.c (store_parm_decls): Likewise. * c-tree.h (struct c_arg_info): Likewise. * tree.h: Update the prototype for get_pending_sizes and put_pending_sizes. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@159085 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/c-tree.h')
-rw-r--r--gcc/c-tree.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/c-tree.h b/gcc/c-tree.h
index 50ed9db08a8..3090a673842 100644
--- a/gcc/c-tree.h
+++ b/gcc/c-tree.h
@@ -306,11 +306,11 @@ struct c_arg_info {
/* A list of non-parameter decls (notably enumeration constants)
defined with the parameters. */
tree others;
/* A list of VLA sizes from the parameters. In a function
definition, these are used to ensure that side-effects in sizes
of arrays converted to pointers (such as a parameter int i[n++])
take place; otherwise, they are ignored. */
- tree pending_sizes;
+ VEC(tree,gc) *pending_sizes;
/* True when these arguments had [*]. */
BOOL_BITFIELD had_vla_unspec : 1;
};
@@ -306,11 +306,11 @@ struct c_arg_info {
defined with the parameters. */
tree others;
- /* A list of VLA sizes from the parameters. In a function
+ /* A VEC of VLA sizes from the parameters. In a function
definition, these are used to ensure that side-effects in sizes
of arrays converted to pointers (such as a parameter int i[n++])